var getNow,
	init,
	isPeek,
	now,
	showCountryTable,
	showInfo,
	updateView;

getNow = function () {
	if (now !== null && now !== undefined) return now;

	// Load current time in UTC
	now = moment.utc();
	now.lang('nl');

	// Convert now to Belgian time (UTC+1)
	now.add('hours', 1);
	return now;
};

init = function () {
	document.getElementById('tarieven-select').addEventListener('change', showCountryTable);

	updateView();
};

isPeek = function () {
	var now = getNow();

	switch (now.day()) {
		case 0:
		case 6:
			return false;
		case 1:
		case 2:
		case 3:
		case 4:
		case 5:
			return (now.hours() >= 8 && (now.hours() < 16 && now.minutes() <= 59));
	}
};

showCountryTable = function () {
	// Hide visible table, if any
	var visibleTable = document.getElementsByClassName('tarieven-selected');
	if (visibleTable.length > 0) {
		visibleTable[0].classList.remove('tarieven-selected');
	}

	// What table to show
	var countrySelect = document.getElementById('tarieven-select');
	var selectedCountry = countrySelect.options[countrySelect.selectedIndex].value.toLowerCase();

	// Show table
	document.getElementById('tarieven-' + selectedCountry).classList.add('tarieven-selected');
};

showInfo = function () {
	var visibleInfo = document.getElementsByClassName('info-selected');
	if (visibleInfo.length > 0) {
		visibleInfo[0].classList.remove('info-selected');
	}

	var show = (isPeek()) ? 'piekuur-info' : 'daluur-info';
	document.getElementById(show).classList.add('info-selected');
};

updateView = function () {
	var now = getNow(),
		timelineClass = (now.day() === 0 || now.day() === 6) ? 'timeline-weekend' : 'timeline-week';

	// Set current time heading
	document.getElementById('current-time').innerHTML = now.format('dddd[,] HH[u]mm');

	// Set current time indicator
	// - 1.6 is a correction because of the spare space left and right (1.1) + width of the indicator itself (.4)
	var xPosition = Math.floor((now.hours() * 60 + now.minutes()) / 1430 * 100) - 2;
	document.getElementById('current-time-indicator').style.left = xPosition + '%';

	// Add correct class to timeline
	document.getElementById('timeline').classList.add(timelineClass);

	// Determine peek
	if (isPeek()) {
		document.getElementById('current-time-indicator').classList.add('peek-time-indicator');
		document.getElementById('current-time-icon').classList.add('current-time-icon-peek');
	} else {
		document.getElementById('current-time-indicator').classList.remove('peek-time-indicator');
		document.getElementById('current-time-icon').classList.remove('current-time-icon-peek');
	}

	// Show correct info
	showInfo();
};

document.addEventListener('DOMContentLoaded', init);